methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel(
'ambient_light.aliyou.dev',
);
The method channel used to interact with the native platform.
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel(
'ambient_light.aliyou.dev',
);